@@ -1,7 +1,16 @@
 use ansi_term::Color;
+use std::process;
 //use super::report_d88::ReportD88;
 use crate::report_d88::ReportD88;
 
+/// Print Error Message
+///
+#[allow(non_snake_case)]
+pub fn ERROR(err_mes: &str) {
+    println!("[ERROR] {}", err_mes);
+    process::exit(0);
+}
+
 impl ReportD88 {
     /// Print Track Bar(Helper function)
     ///
@@ -37,7 +46,7 @@ impl ReportD88 {
     ///
     ///   * Return the value of `offset` plus 16.
     ///
-    pub fn print_16byte(&mut self, buf16: &[u8], offset: usize, color: ansi_term::Color) -> usize {
+    pub fn print_16byte(&self, buf16: &[u8], offset: u64, color: ansi_term::Color) -> u64 {
         self.print_16byte_len(buf16, offset, color, 16)
     }
 
@@ -57,13 +66,14 @@ impl ReportD88 {
     ///
     ///   * Return the value of `offset` plus 16.
     ///
+    #[allow(clippy::format_in_format_args)]
     pub fn print_16byte_len(
-        &mut self,
+        &self,
         buf16: &[u8],
-        offset: usize,
+        offset: u64,
         color: ansi_term::Color,
         length: usize,
-    ) -> usize {
+    ) -> u64 {
         let mut char_pat = [
             '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.', '.',
         ];
@@ -75,6 +85,7 @@ impl ReportD88 {
         if !self.nocolor_flg {
             print!("{}  ", Color::Cyan.paint(&(format!("{:05x}", offset))));
         } else {
+            //#[allow(clippy::format_in_format_args)]
             print!("{}  ", format!("{:05x}", offset));
         }
 
@@ -107,6 +118,6 @@ impl ReportD88 {
 
         //
         //
-        offset + length
+        offset + length as u64
     }
 }
